/**
 * Copyright (c) 2005 JavaPlant Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.javaplant.portlets;

import java.net.URL;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;

/**
 * @author Brad Smith <mvcportlet@gmail.com>
 *         Date: Sep 19, 2005
 */
public class HttpQuery {

    private URL url;
    private HttpURLConnection httpURLConnection;
    private StringBuffer responseContent;
    private int statusCode=-1;

    private static final int DEFAULT_BUFFER_SIZE = 16384;// 16K
    private String httpProxyHost;
    private boolean queryComplete = true;


    public HttpQuery(URL url) {
        this.url = url;
    }

    public URL getUrl() {
        return url;
    }

    public void setUrl(URL url) {
        this.url = url;
    }

    public String getHttpProxyHost() {
        return httpProxyHost;
    }

    public void setHttpProxyHost(String httpProxyHost) {
        this.httpProxyHost = httpProxyHost;
        System.setProperty("http.proxyHost",this.httpProxyHost);
    }

    public String getResponseContentString() {
        return (responseContent == null) ? null : responseContent.toString();
    }

    public byte [] getResponseContentBytes() {
        return (responseContent == null) ? new byte[0] : responseContent.toString().getBytes();
    }

    public int getStatusCode() {
        return statusCode;
    }

    public boolean isQueryComplete() {
        return queryComplete;
    }

    public synchronized void doQuery() {
        queryComplete = false;
        try {
            // prepare httpURLConnection
            doPreQuery();
            // connect

            httpURLConnection = (HttpURLConnection)url.openConnection();
            httpURLConnection.setInstanceFollowRedirects(true);
            httpURLConnection.connect();
            char [] buffer = new char[ DEFAULT_BUFFER_SIZE ];
            BufferedReader bfread = new BufferedReader(new InputStreamReader(httpURLConnection.getInputStream()));
            responseContent = new StringBuffer();
            int totalRead = 0, read = 0;
            while (read >= 0) {
                read = bfread.read(buffer);
                if (read != -1) {
                    responseContent.append(buffer, 0, read);
                    totalRead += read;
                }
            }
            // do actual query
            doSend();
            // allow subclasses a chance to do something
            doPostQuery();
            // close and cleanup
            httpURLConnection.disconnect();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            queryComplete = true;
        }
    }

    protected void doPreQuery() {}
    protected void doPostQuery() {}
    protected void doSend() {}

    public static void main(String [] args) {
        HttpQuery query = null;
        try {
            query = new HttpQuery(new URL("http://www.wunderground.com/auto/rss_full/MA/Brookline.xml"));
            query.doQuery();
            System.out.println(query.getResponseContentString());
        } catch (MalformedURLException e) {
            e.printStackTrace();
        }
    }
}
