/**
 * Copyright (c) 2005 JavaPlant Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.javaplant.portlets;

import java.io.IOException;
import java.net.URL;
import java.util.List;
import java.util.Iterator;
import java.util.Map;
import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletException;
import javax.portlet.PortletMode;
import javax.portlet.PortletPreferences;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import com.javaplant.portlet.BaseMVCPortlet;
import com.javaplant.portlet.PortletForm;
import com.javaplant.portlet.PortletPage;

/** This portlet provides a several examples of how to use the Simple MVC Portlet Framework.
 * - examples of all the init params
 * - example of view mode (get and render RSS feeds)
 * - example of edit mode (enter and store preferences)
 * - example of help mode (show a simple page that explains how to use the portlet)
 * - example of validate()
 *
 * @author Brad Smith <mvcportlet@gmail.com>
 *         Date: Sep 18, 2005
 */
public class RSSFeedPortlet extends BaseMVCPortlet {


    protected void doValidationFailed(PortletForm portletForm) throws PortletException, IOException {
        // TODO: Implement me
    }

    protected void doProcessAction(PortletForm portletForm, ActionRequest actionRequest, ActionResponse actionResponse)
        throws PortletException, IOException {

        log.info("doProcessAction()");
        RSSFeedPortletForm form = (RSSFeedPortletForm)portletForm;
        log.info("form:\n"+form);
        if ("addRow".equals(form.getAction())) {
            form.getRssFeedConfiguration().addEmptyRow();
            form.setLoadPortletPreferences(false);
        } else if ("removeRow".equals(form.getAction())) {
            String rowNumStr = form.getRowNumber();
            if (!"".equals(rowNumStr)) {
                try {
                    form.getRssFeedConfiguration().removeRow(Integer.parseInt(rowNumStr));
                } catch (NumberFormatException e) {
                    log.error(e);
                }
            }
            form.setLoadPortletPreferences(false);
        } else if ("savePrefs".equals(form.getAction())) {
            // TODO - if validated...
            final PortletPreferences portletPrefs = actionRequest.getPreferences();
            final Map prefsToSave = form.getRssFeedConfiguration().getPreferencesMap();
            String key = null;
            for (Iterator it=prefsToSave.keySet().iterator();it.hasNext();key = (String)it.next()) {
                final Object value = prefsToSave.get(key);
                if (value instanceof String) {
                    portletPrefs.setValue(key,(String)value);
                } else if (value instanceof String[]) {
                    portletPrefs.setValues(key,(String[])value);
                }
            }
            portletPrefs.store();
            actionResponse.setPortletMode(PortletMode.VIEW);
        } else if ("cancel".equals(form.getAction())) {
            actionResponse.setPortletMode(PortletMode.VIEW);
        }
    }

    protected PortletPage doViewRender(PortletForm portletForm, RenderRequest renderRequest, RenderResponse renderResponse)
        throws PortletException, IOException {

        final RSSFeedPortletForm rssForm = (RSSFeedPortletForm)portletForm;
        // get exisiting PortletPreferences and obtain RSS Feeds
        if (rssForm.isLoadPortletPreferences()) {
            final PortletPreferences portletPrefs = renderRequest.getPreferences();
            RSSFeedConfiguration.setProperties(rssForm.getRssFeedConfiguration(),portletPrefs.getMap());
        }
        final String httpProxyHost = rssForm.getRssFeedConfiguration().getHttpProxyHost();
        final long timeout = rssForm.getRssFeedConfiguration().getTimeout();
        final List rssUrls = rssForm.getRssFeedConfiguration().getRssURLs();
        for (Iterator it = rssUrls.iterator(); it.hasNext();) {
            final String rssURL = (String) it.next();
            final HttpQuery query = new HttpQuery(new URL(rssURL));
            if (!"".equals(httpProxyHost)) {
                query.setHttpProxyHost(httpProxyHost);
            }
            query.doQuery();
            long expTime = 0;
            if (timeout > 0) {
                expTime = System.currentTimeMillis() + timeout * 1000;
            } else {
            // Don't like this kind of polling...should look at threads
                while (!query.isQueryComplete() || (System.currentTimeMillis() - expTime) < 0) ;// NO OP //
            }
            rssForm.addRssFeedContent(query.getResponseContentString());
        }
        // Render View
        return new PortletPage(getViewPage());
    }

    protected PortletPage doEditRender(PortletForm portletForm, RenderRequest renderRequest, RenderResponse renderResponse) throws PortletException, IOException {
        final RSSFeedPortletForm rssForm = (RSSFeedPortletForm)portletForm;
        if (rssForm.isLoadPortletPreferences()) { // get exisiting PortletPreferences and obtain RSS Feeds
            final PortletPreferences portletPrefs = renderRequest.getPreferences();
            RSSFeedConfiguration.setProperties(rssForm.getRssFeedConfiguration(),portletPrefs.getMap());
        }
        return new PortletPage(getEditPage());
    }

}
