/**
 * Copyright (c) 2005 JavaPlant Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.javaplant.portlet;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/** This class holds a specific BaseMVCPortlet configuration.
 *
 * <init-param>
 *    <description>Form class to instantiate for this portlet (like a Struts ActionForm).</description>
 *    <name>portlet.form</name>
 *    <value>com.javaplant.forms.ProductionStatusForm</value>
 *  </init-param>
 *  <init-param>
 *    <description>JSP (fragment) to use for rendering the portlet in view mode.</description>
 *    <name>portlet.jsp.view</name>
 *    <value>/WEB-INF/jsp/production-status/view.jsp</value>
 *  </init-param>
 *  <init-param>
 *    <description>JSP (fragment) to use for rendering the portlet in edit mode.</description>
 *    <name>portlet.jsp.edit</name>
 *    <value>/WEB-INF/jsp/production-status/edit.jsp</value>
 *  </init-param>
 *  <init-param>
 *    <description>JSP (fragment) to use for rendering the portlet in help mode.</description>
 *    <name>portlet.jsp.help</name>
 *    <value>/WEB-INF/jsp/production-status/help.jsp</value>
 *  </init-param>
 *
 * @author Brad Smith <mvcportlet@gmail.com>
 *         Date: Aug 14, 2005
 */
public class PortletConfiguration {

    private final Log log = LogFactory.getLog(PortletConfiguration.class);

    private Class portletFormClass;
    private Map portletPages = new HashMap();
    private String viewPage;
    private String editPage;
    private String helpPage;
    private boolean showConfiguration = false;

    public PortletConfiguration() {
    }

    public final Class getPortletFormClass() {
        return portletFormClass;
    }

    /* package */ final void setPortletFormClass(Class portletFormClass) {
        this.portletFormClass = portletFormClass;
    }

    public final String getViewPage() {
        return viewPage;
    }

    public final void setViewPage(String viewPage) {
        this.viewPage = viewPage;
    }

    public final String getEditPage() {
        return editPage;
    }

    public final void setEditPage(String editPage) {
        this.editPage = editPage;
    }

    public final String getHelpPage() {
        return helpPage;
    }

    public final void setHelpPage(String helpPage) {
        this.helpPage = helpPage;
    }

    public final String getPage(String pageName) {
        return (String)this.portletPages.get(pageName);
    }

    /* package */ final void setPage(String pageName, String pageFrag) {
        if (pageName != null && pageFrag != null) {
            this.portletPages.put(pageName,pageFrag);
        } else {
            log.info("pageName="+pageName+",\tpageFrag="+pageFrag+" not added to PortletConfiguration.");
        }
    }

    public final Map getPages() {
        return Collections.unmodifiableMap(this.portletPages);
    }

    public final boolean isShowConfiguration() {
        return showConfiguration;
    }

    public final void setShowConfiguration(boolean showConfiguration) {
        this.showConfiguration = showConfiguration;
    }

}
