/**
 * Copyright (c) 2005 JavaPlant Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 */
package com.javaplant.portlet;

import java.util.ArrayList;
import java.util.ResourceBundle;
import javax.portlet.PortletMode;

/** Base class for portlet forms.

 * @author Brad Smith <mvcportlet@gmail.com>
 *         Date: Aug 14, 2005
 */
public abstract class PortletForm {

    public static final String KEY = "portletForm";

    private String action;
    private String jspPage;
    private PortletMode portletMode = new PortletMode("VIEW");
    private ResourceBundle resourceBundle;
    private String [] errors = new String[0];

    public final String getAction() {
        return action;
    }

    public final void setAction(String action) {
        this.action = (action == null) ? "" : action.trim();
    }

    public final String getJspPage() {
        return jspPage;
    }

    public void setJspPage(String jspPage) {
        this.jspPage = (jspPage == null) ? "" : jspPage.trim();
    }

    public final PortletMode getPortletMode() {
        return portletMode;
    }

    public final void setPortletMode(PortletMode portletMode) {
        this.portletMode = portletMode;
    }

    public final ResourceBundle getResourceBundle() {
        return resourceBundle;
    }

    public final void setResourceBundle(ResourceBundle resourceBundle) {
        this.resourceBundle = resourceBundle;
    }

    public final String[] getErrors() {
        return errors;
    }

    public final void setErrors(String[] errors) {
        this.errors = errors;
    }

    public final void setErrorKeys(String [] errorKeys) {
        if (errorKeys == null || errorKeys.length==0) {
            this.errors = new String[0];
            return;
        }
        // look for errors in resource bundle
        if (this.resourceBundle == null) {
            this.errors = new String[1];
            this.errors[0] = "Error:  There was a problem - please try again.";
            return;
        }
        ArrayList errs = new ArrayList();
        for (int i=0;i<errorKeys.length;i++) {
            String errMsg = resourceBundle.getString(errorKeys[i]);
            if (errMsg != null && !"".equals(errMsg)) {
                errs.add(errMsg);
            }
        }
        this.errors = (String [])errs.toArray(new String[errs.size()]);
    }

    public abstract boolean validate();

    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("PortletForm");
        buf.append("{action=").append(action);
        buf.append(",portletMode=").append(portletMode);
        buf.append('}');
        return buf.toString();
    }
}
