/**
 * Copyright (c) 2005 JavaPlant Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.javaplant.taglib;

import javax.portlet.RenderRequest;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.Tag;
import javax.servlet.jsp.tagext.TagSupport;
import com.javaplant.portlet.PortletForm;

/** Create a page-scoped reference to a portlet form.  The portlet form is obtained for the portlet's
 * RenderRequest object.
 *
 * @author Brad Smith <mvcportlet@gmail.com>
 */
public final class BindPortletFormTag extends TagSupport {

    private String formName = PortletForm.KEY;

    public BindPortletFormTag() {
    }

    public final void setFormName(String formName) {
        this.formName = (formName==null) ? PortletForm.KEY : formName;
    }

   public final void release() {
       this.formName = PortletForm.KEY;
       super.release();
   }

   public final int doStartTag() throws JspException {
      return Tag.SKIP_BODY;
   }

   public final int doEndTag() throws JspException {
       final RenderRequest renderRequest = (RenderRequest)pageContext.getAttribute("renderRequest");
       if (renderRequest == null) {
           throw new JspException("ERROR:  javax.portlet.RenderRequest is not available for this page."
                                 +"\nBe sure to use JSR-168 <portlet:defineObjects/> tag before using <jp:bindPortletForm/>."
           );
       }
       pageContext.setAttribute(this.formName,renderRequest.getAttribute(this.formName));
       return Tag.EVAL_PAGE;
   }
}
