/**
 * Copyright (c) 2005 JavaPlant Software.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.javaplant.taglib;

import java.io.IOException;
import javax.portlet.RenderRequest;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.BodyTagSupport;
import com.javaplant.portlet.PortletUtils;

/** Render the enclosed body content if user is in role.
 *
 * @author Brad Smith <mvcportlet@gmail.com>
 *         Date: Jun 28, 2005
 */
public final class RenderBodyIfUserIsInRoleTag extends BodyTagSupport {

    private String role = "";

    public RenderBodyIfUserIsInRoleTag() {
    }

    public final void setRole(String role) {
        this.role = (role==null) ? "" : role ;
    }

    public final void release() {
        this.role = "";
        super.release();
    }

   public final int doStartTag() throws JspException {
      boolean userHasRole = false;
      if (!"".equals(role)) {
          final RenderRequest renderRequest = (RenderRequest)pageContext.getAttribute("renderRequest");
          if (renderRequest == null) {
              throw new JspException("ERROR:  javax.portlet.RenderRequest is not available for this page."
                                    +"\nBe sure to use JSR-168 <portlet:defineObjects/> tag before using <jp:renderIfIn role=\"...\"/>."
              );
          }
          userHasRole = PortletUtils.isUserInRole(role,renderRequest);
      }
      return (userHasRole) ? BodyTagSupport.EVAL_BODY_BUFFERED : BodyTagSupport.SKIP_BODY;
   }

   public final int doAfterBody() throws JspException {
       try {
           getBodyContent().writeOut(getBodyContent().getEnclosingWriter());
       } catch (IOException e) {
           throw new JspException(e.getMessage(),e);
       }
       return BodyTagSupport.SKIP_BODY;
   }

}
